### MMGen version 0.9.0 Release Notes

#### New features:

  - New `mmgen-txdo` command creates, signs and sends transactions in one operation
  - Exporting seed to hexadecimal (mmhex) format now supported
  - Support for 8-color terminals, better default colors on 256-color terminals
  - `--force-256-color` option overrides terminfo entry and $TERM environment variable
  - Selected commands of `mmgen-tool` now accept stdin input
  - Transaction file format change: TXID appended to file after tx is broadcast

A new tutorial, [Recovering Keys Without MMGen][01], has been added to the wiki

[01]: https://github.com/mmgen/mmgen/wiki/Recovering-Keys-Without-MMGen
